
-- modify database schema created by amavis

-- add foreign key constraint for users(policy_id) -> policy(id)
ALTER TABLE users 
  ADD CONSTRAINT users_policy_id_fkey FOREIGN KEY (policy_id) 
    REFERENCES policy(id) 
    ON DELETE CASCADE;

-- make sure policy names are unique
ALTER TABLE policy
  ADD CONSTRAINT policy_policy_name_key UNIQUE (policy_name);

-- create additional tables used by myAmavis

CREATE TABLE userauth
(
  id serial NOT NULL,
  userid text,
  email_id int4,
  CONSTRAINT userauth_pkey PRIMARY KEY (id),
  CONSTRAINT userauth_email_id_fkey FOREIGN KEY (email_id)
      REFERENCES users (id) MATCH SIMPLE
      ON DELETE CASCADE
); 

CREATE TABLE adminusers
(
  id serial NOT NULL,
  userid text,
  CONSTRAINT adminusers_pkey PRIMARY KEY (id),
  CONSTRAINT adminusers_userid_key UNIQUE (userid)
);



-- because of the direct join with the users table recipient addresses
-- will be directly mapped to entries in the users table. this will not
-- work when there are catch-all-entries ('@example.com') in the users
-- table!
-- so if you want the statistics to be correct your users table must 
-- contain only complete email addresses, no catch-alls!

CREATE OR REPLACE VIEW mailsflat AS 
 SELECT m.mail_id, m.secret_id, m.am_id, m.time_num, m.time_iso, 
        m.sid, m.policy, m.client_addr, m.size, m.content, m.quar_type, 
        m.quar_loc, m.dsn_sent, m.spam_level, m.message_id, 
        m.from_addr, m.subject, m.host, 
        mas."domain" AS sdomain, mas.email AS sender, 
        r.rid, r.ds, r.rs, r.bl, r.wl, r.bspam_level, 
        mar."domain" AS rdomain, mar.email AS recipient, 
        u.id AS user_id, 
        p.id AS policy_id, p.policy_name

   FROM msgs m
     JOIN maddr mas ON m.sid = mas.id
     JOIN msgrcpt r ON m.mail_id::text = r.mail_id::text
     JOIN maddr mar ON r.rid = mar.id
     LEFT JOIN users u ON mar.email = u.email
     LEFT JOIN policy p ON u.policy_id = p.id

  WHERE m.content IS NOT NULL;

